﻿//
// TranslateTags.cs
//
// Author: Kees van Spelde <sicos2002@hotmail.com>
//
// Copyright (c) 2015-2021 Magic-Sessions. (www.magic-sessions.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NON INFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using System.Linq;

namespace MsgKit
{
    /// <summary>
    ///     This class maps each MAPI property to the corresponding canonical property name (and the otherway around).
    /// </summary>
    /// <remarks>
    ///     See https://msdn.microsoft.com/en-us/library/office/cc815492.aspx
    /// </remarks>
    internal static class TranslateTags
    {
        private static readonly Dictionary<string, string> Properties =
            new Dictionary<string, string>(StringComparer.InvariantCultureIgnoreCase);

        #region Constructor
        /// <summary>
        ///     Creates this object and sets all it's properties
        /// </summary>
        static TranslateTags()
        {
            Properties.Add("dispidABPArrayType", "PidLidAddressBookProviderArrayType");
            Properties.Add("dispidABPEmailList", "PidLidAddressBookProviderEmailList");
            Properties.Add("dispidAddressCountryCode", "PidLidAddressCountryCode");
            Properties.Add("dispidAgingDontAgeMe", "PidLidAgingDontAgeMe");
            Properties.Add("dispidAllAttendeesString", "PidLidAllAttendeesString");
            Properties.Add("dispidAnniversaryEventEID", "PidLidAnniversaryEventEntryId");
            Properties.Add("dispidApptAuxFlags", "PidLidAppointmentAuxiliaryFlags");
            Properties.Add("dispidApptColor", "PidLidAppointmentColor");
            Properties.Add("dispidApptCounterProposal", "PidLidAppointmentCounterProposal");
            Properties.Add("dispidApptDuration", "PidLidAppointmentDuration");
            Properties.Add("dispidApptEndWhole", "PidLidAppointmentEndWhole");
            Properties.Add("dispidApptLastSequence", "PidLidAppointmentLastSequence");
            Properties.Add("dispidApptMessageClass", "PidLidAppointmentMessageClass");
            Properties.Add("dispidApptNotAllowPropose", "PidLidAppointmentNotAllowPropose");
            Properties.Add("dispidApptProposalNum", "PidLidAppointmentProposalNumber");
            Properties.Add("dispidApptProposedDuration", "PidLidAppointmentProposedDuration");
            Properties.Add("dispidApptProposedEndWhole", "PidLidAppointmentProposedEndWhole");
            Properties.Add("dispidApptProposedStartWhole", "PidLidAppointmentProposedStartWhole");
            Properties.Add("dispidApptRecur", "PidLidAppointmentRecur");
            Properties.Add("dispidApptReplyName", "PidLidAppointmentReplyName");
            Properties.Add("dispidApptReplyTime", "PidLidAppointmentReplyTime");
            Properties.Add("dispidApptSeqTime", "PidLidAppointmentSequenceTime");
            Properties.Add("dispidApptSequence", "PidLidAppointmentSequence");
            Properties.Add("dispidApptStartWhole", "PidLidAppointmentStartWhole");
            Properties.Add("dispidApptStateFlags", "PidLidAppointmentStateFlags");
            Properties.Add("dispidApptSubType", "PidLidAppointmentSubType");
            Properties.Add("dispidApptTZDefEndDisplay", "PidLidAppointmentTimeZoneDefinitionEndDisplay");
            Properties.Add("dispidApptTZDefRecur", "PidLidAppointmentTimeZoneDefinitionRecur");
            Properties.Add("dispidApptTZDefStartDisplay", "PidLidAppointmentTimeZoneDefinitionStartDisplay");
            Properties.Add("dispidApptUnsendableRecips", "PidLidAppointmentUnsendableRecipients");
            Properties.Add("dispidAutoFillLocation", "PidLidAutoFillLocation");
            Properties.Add("dispidAutoLog", "PidLidAutoLog");
            Properties.Add("dispidBCCardPicture", "PidLidBusinessCardCardPicture");
            Properties.Add("dispidBCDisplayDefinition", "PidLidBusinessCardDisplayDefinition");
            Properties.Add("dispidBilling", "PidLidBilling");
            Properties.Add("dispidBirthdayEventEID", "PidLidBirthdayEventEntryId");
            Properties.Add("dispidBusyStatus", "PidLidBusyStatus");
            Properties.Add("dispidCategories", "PidLidCategories");
            Properties.Add("dispidCCAttendeesString", "PidLidCcAttendeesString");
            Properties.Add("dispidChangeHighlight", "PidLidChangeHighlight");
            Properties.Add("dispidClassDesc", "PidLidClassificationDescription");
            Properties.Add("dispidClassGuid", "PidLidClassificationGuid");
            Properties.Add("dispidClassification", "PidLidClassification");
            Properties.Add("dispidClassified", "PidLidClassified");
            Properties.Add("dispidClassKeep", "PidLidClassificationKeep");
            Properties.Add("dispidCleanGlobalObjId", "PidLidCleanGlobalObjectId");
            Properties.Add("dispidClipEnd", "PidLidClipEnd");
            Properties.Add("dispidClipStart", "PidLidClipStart");
            Properties.Add("dispidCommonEnd", "PidLidCommonEnd");
            Properties.Add("dispidCommonStart", "PidLidCommonStart");
            Properties.Add("dispidCompanies", "PidLidCompanies");
            Properties.Add("dispidContactCharSet", "PidLidContactCharacterSet");
            Properties.Add("dispidContactItemData", "PidLidContactItemData");
            Properties.Add("dispidContactLinkEntry", "PidLidContactLinkEntry");
            Properties.Add("dispidContactLinkName", "PidLidContactLinkName");
            Properties.Add("dispidContactLinkSearchKey", "PidLidContactLinkSearchKey");
            Properties.Add("dispidContacts", "PidLidContacts");
            Properties.Add("dispidContactUserField1", "PidLidContactUserField1");
            Properties.Add("dispidContactUserField2", "PidLidContactUserField2");
            Properties.Add("dispidContactUserField3", "PidLidContactUserField3");
            Properties.Add("dispidContactUserField4", "PidLidContactUserField4");
            Properties.Add("dispidCurrentVersion", "PidLidCurrentVersion");
            Properties.Add("dispidCurrentVersionName", "PidLidCurrentVersionName");
            Properties.Add("dispidCustomFlag", "PidLidCustomFlag");
            Properties.Add("dispidDLChecksum", "PidLidDistributionListChecksum");
            Properties.Add("dispidDLMembers", "PidLidDistributionListMembers");
            Properties.Add("dispidDLName", "PidLidDistributionListName");
            Properties.Add("dispidDLOneOffMembers", "PidLidDistributionListOneOffMembers");
            Properties.Add("dispidEmail1AddrType", "PidLidEmail1AddressType");
            Properties.Add("dispidEmail1DisplayName", "PidLidEmail1DisplayName");
            Properties.Add("dispidEmail1EmailAddress", "PidLidEmail1EmailAddress");
            Properties.Add("dispidEmail1OriginalDisplayName", "PidLidEmail1OriginalDisplayName");
            Properties.Add("dispidEmail1OriginalEntryID", "PidLidEmail1OriginalEntryId");
            Properties.Add("dispidEmail2AddrType", "PidLidEmail2AddressType");
            Properties.Add("dispidEmail2DisplayName", "PidLidEmail2DisplayName");
            Properties.Add("dispidEmail2EmailAddress", "PidLidEmail2EmailAddress");
            Properties.Add("dispidEmail2OriginalDisplayName", "PidLidEmail2OriginalDisplayName");
            Properties.Add("dispidEmail2OriginalEntryID", "PidLidEmail2OriginalEntryId");
            Properties.Add("dispidEmail3AddrType", "PidLidEmail3AddressType");
            Properties.Add("dispidEmail3DisplayName", "PidLidEmail3DisplayName");
            Properties.Add("dispidEmail3EmailAddress", "PidLidEmail3EmailAddress");
            Properties.Add("dispidEmail3OriginalDisplayName", "PidLidEmail3OriginalDisplayName");
            Properties.Add("dispidEmail3OriginalEntryID", "PidLidEmail3OriginalEntryId");
            Properties.Add("dispidEMSAbX509Cert", "PidLidUserX509Certificate");
            Properties.Add("dispidExceptionReplaceTime", "PidLidExceptionReplaceTime");
            Properties.Add("dispidFax1AddrType", "PidLidFax1AddressType");
            Properties.Add("dispidFax1DisplayName", "PidLidFax1DisplayName");
            Properties.Add("dispidFax1EmailAddress", "PidLidFax1EmailAddress");
            Properties.Add("dispidFax1EmailType", "PidLidFax1EmailType");
            Properties.Add("dispidFax1EntryID", "PidLidFax1EntryId");
            Properties.Add("dispidFax1OriginalDisplayName", "PidLidFax1OriginalDisplayName");
            Properties.Add("dispidFax1OriginalEntryID", "PidLidFax1OriginalEntryId");
            Properties.Add("dispidFax1RTF", "PidLidFax1RichTextFormat");
            Properties.Add("dispidFax2AddrType", "PidLidFax2AddressType");
            Properties.Add("dispidFax2DisplayName", "PidLidFax2DisplayName");
            Properties.Add("dispidFax2EmailAddress", "PidLidFax2EmailAddress");
            Properties.Add("dispidFax2EmailType", "PidLidFax2EmailType");
            Properties.Add("dispidFax2EntryID", "PidLidFax2EntryId");
            Properties.Add("dispidFax2OriginalDisplayName", "PidLidFax2OriginalDisplayName");
            Properties.Add("dispidFax2OriginalEntryID", "PidLidFax2OriginalEntryId");
            Properties.Add("dispidFax2RTF", "PidLidFax2RichTextFormat");
            Properties.Add("dispidFax3AddrType", "PidLidFax3AddressType");
            Properties.Add("dispidFax3DisplayName", "PidLidFax3DisplayName");
            Properties.Add("dispidFax3EmailAddress", "PidLidFax3EmailAddress");
            Properties.Add("dispidFax3EmailType", "PidLidFax3EmailType");
            Properties.Add("dispidFax3EntryID", "PidLidFax3EntryId");
            Properties.Add("dispidFax3OriginalDisplayName", "PidLidFax3OriginalDisplayName");
            Properties.Add("dispidFax3OriginalEntryID", "PidLidFax3OriginalEntryId");
            Properties.Add("dispidFax3RTF", "PidLidFax3RichTextFormat");
            Properties.Add("dispidFExceptionalAttendees", "PidLidFExceptionalAttendees");
            Properties.Add("dispidFExceptionalBody", "PidLidFExceptionalBody");
            Properties.Add("dispidFileUnder", "PidLidFileUnder");
            Properties.Add("dispidFileUnderId", "PidLidFileUnderId");
            Properties.Add("dispidFileUnderList", "PidLidFileUnderList");
            Properties.Add("dispidFInvited", "PidLidFInvited");
            Properties.Add("dispidFlagStringEnum", "PidLidFlagString");
            Properties.Add("dispidFreeBusyLocation", "PidLidFreeBusyLocation");
            Properties.Add("dispidFShouldTNEF", "PidLidFShouldTNEF");
            Properties.Add("dispidFwrdInstance", "PidLidForwardInstance");
            Properties.Add("dispidHasPicture", "PidLidHasPicture");
            Properties.Add("dispidHeaderItem", "PidLidHeaderItem");
            Properties.Add("dispidHomeAddress", "PidLidHomeAddress");
            Properties.Add("dispidHomeAddressCountryCode", "PidLidHomeAddressCountryCode");
            Properties.Add("dispidHTML", "PidLidHtml");
            Properties.Add("dispidImapDeleted", "PidLidImapDeleted");
            Properties.Add("dispidImgAttchmtsCompressLevel", "PidLidImageAttachmentsCompressionLevel");
            Properties.Add("dispidInetAcctName", "PidLidInternetAccountName");
            Properties.Add("dispidInetAcctStamp", "PidLidInternetAccountStamp");
            Properties.Add("dispidInstMsg", "PidLidInstantMessagingAddress");
            Properties.Add("dispidIntendedBusyStatus", "PidLidIntendedBusyStatus");
            Properties.Add("dispidIsIPFax", "PidLidIsInterpersonalFax");
            Properties.Add("dispidLinkedTaskItems", "PidLidLinkedTaskItems");
            Properties.Add("dispidLocation", "PidLidLocation");
            Properties.Add("dispidLogDocPosted", "PidLidLogDocumentPosted");
            Properties.Add("dispidLogDocPrinted", "PidLidLogDocumentPrinted");
            Properties.Add("dispidLogDocRouted", "PidLidLogDocumentRouted");
            Properties.Add("dispidLogDocSaved", "PidLidLogDocumentSaved");
            Properties.Add("dispidLogDuration", "PidLidLogDuration");
            Properties.Add("dispidLogEnd", "PidLidLogEnd");
            Properties.Add("dispidLogFlags", "PidLidLogFlags");
            Properties.Add("dispidLogStart", "PidLidLogStart");
            Properties.Add("dispidLogType", "PidLidLogType");
            Properties.Add("dispidLogTypeDesc", "PidLidLogTypeDesc");
            Properties.Add("dispidMeetingType", "PidLidMeetingType");
            Properties.Add("dispidMileage", "PidLidMileage");
            Properties.Add("dispidMWSURL", "PidLidMeetingWorkspaceUrl");
            Properties.Add("dispidNonSendableBCC", "PidLidNonSendableBcc");
            Properties.Add("dispidNonSendableCC", "PidLidNonSendableCc");
            Properties.Add("dispidNonSendableTo", "PidLidNonSendableTo");
            Properties.Add("dispidNonSendBccTrackStatus", "PidLidNonSendBccTrackStatus");
            Properties.Add("dispidNonSendCcTrackStatus", "PidLidNonSendCcTrackStatus");
            Properties.Add("dispidNonSendToTrackStatus", "PidLidNonSendToTrackStatus");
            Properties.Add("dispidNoteColor", "PidLidNoteColor");
            Properties.Add("dispidNoteHeight", "PidLidNoteHeight");
            Properties.Add("dispidNoteWidth", "PidLidNoteWidth");
            Properties.Add("dispidNoteX", "PidLidNoteX");
            Properties.Add("dispidNoteY", "PidLidNoteY");
            Properties.Add("dispidOfflineStatus", "PidLidOfflineStatus");
            Properties.Add("dispidOldLocation", "PidLidOldLocation");
            Properties.Add("dispidOldWhenEndWhole", "PidLidOldWhenEndWhole");
            Properties.Add("dispidOldWhenStartWhole", "PidLidOldWhenStartWhole");
            Properties.Add("dispidOrigStoreEid", "PidLidOriginalStoreEntryId");
            Properties.Add("dispidOtherAddress", "PidLidOtherAddress");
            Properties.Add("dispidOtherAddressCountryCode", "PidLidOtherAddressCountryCode");
            Properties.Add("dispidPercentComplete", "PidLidPercentComplete");
            Properties.Add("dispidPostalAddressId", "PidLidPostalAddressId");
            Properties.Add("dispidPostRssChannel", "PidLidPostRssChannel");
            Properties.Add("dispidPostRssChannelLink", "PidLidPostRssChannelLink");
            Properties.Add("dispidPrivate", "PidLidPrivate");
            Properties.Add("dispidPropDefStream", "PidLidPropertyDefinitionStream");
            Properties.Add("dispidRecallTime", "PidLidRecallTime");
            Properties.Add("dispidRecurPattern", "PidLidRecurrencePattern");
            Properties.Add("dispidRecurring", "PidLidRecurring");
            Properties.Add("dispidRecurType", "PidLidRecurrenceType");
            Properties.Add("dispidReferenceEID", "PidLidReferenceEntryId");
            Properties.Add("dispidReminderDelta", "PidLidReminderDelta");
            Properties.Add("dispidReminderFileParam", "PidLidReminderFileParameter");
            Properties.Add("dispidReminderNextTime", "PidLidReminderSignalTime");
            Properties.Add("dispidReminderOverride", "PidLidReminderOverride");
            Properties.Add("dispidReminderPlaySound", "PidLidReminderPlaySound");
            Properties.Add("dispidReminderSet", "PidLidReminderSet");
            Properties.Add("dispidReminderTime", "PidLidReminderTime");
            Properties.Add("dispidRemoteAttachment", "PidLidRemoteAttachment");
            Properties.Add("dispidRemoteEID", "PidLidRemoteEntryId");
            Properties.Add("dispidRemoteMsgClass", "PidLidRemoteMessageClass");
            Properties.Add("dispidRemoteSearchKey", "PidLidRemoteSearchKey");
            Properties.Add("dispidRemoteXferSize", "PidLidRemoteTransferSize");
            Properties.Add("dispidRemoteXferTime", "PidLidRemoteTransferTime");
            Properties.Add("dispidRemoteXP", "PidLidRemoteTransport");
            Properties.Add("dispidRequest", "PidLidFlagRequest");
            Properties.Add("dispidResendTime", "PidLidResendTime");
            Properties.Add("dispidResponseStatus", "PidLidResponseStatus");
            Properties.Add("dispidSendMtgAsICAL", "PidLidSendMeetingAsIcal");
            Properties.Add("dispidSharingCaps", "PidLidSharingCapabilities");
            Properties.Add("dispidSharingConfigUrl", "PidLidSharingConfigurationUrl");
            Properties.Add("dispidSharingFlavor", "PidLidSharingFlavor");
            Properties.Add("dispidSharingInitiatorEid", "PidLidSharingInitiatorEntryId");
            Properties.Add("dispidSharingInitiatorName", "PidLidSharingInitiatorName");
            Properties.Add("dispidSharingInitiatorSmtp", "PidLidSharingInitiatorSmtp");
            Properties.Add("dispidSharingLocalType", "PidLidSharingLocalType");
            Properties.Add("dispidSharingProviderGuid", "PidLidSharingProviderGuid");
            Properties.Add("dispidSharingProviderName", "PidLidSharingProviderName");
            Properties.Add("dispidSharingProviderUrl", "PidLidSharingProviderUrl");
            Properties.Add("dispidSharingRemoteName", "PidLidSharingRemoteName");
            Properties.Add("dispidSharingRemoteStoreUid", "PidLidSharingRemoteStoreUid");
            Properties.Add("dispidSharingRemoteType", "PidLidSharingRemoteType");
            Properties.Add("dispidSharingRemoteUid", "PidLidSharingRemoteUid");
            Properties.Add("dispidSharingResponseTime", "PidLidSharingResponseTime");
            Properties.Add("dispidSharingResponseType", "PidLidSharingResponseType");
            Properties.Add("dispidSideEffects", "PidLidSideEffects");
            Properties.Add("dispidSmartNoAttach", "PidLidSmartNoAttach");
            Properties.Add("dispidSniffState", "PidLidAutoProcessState");
            Properties.Add("dispidSpamOriginalFolder", "PidLidSpamOriginalFolder");
            Properties.Add("dispidTaskAccepted", "PidLidTaskAccepted");
            Properties.Add("dispidTaskActualEffort", "PidLidTaskActualEffort");
            Properties.Add("dispidTaskComplete", "PidLidTaskComplete");
            Properties.Add("dispidTaskDateCompleted", "PidLidTaskDateCompleted");
            Properties.Add("dispidTaskDeadOccur", "PidLidTaskDeadOccurrence");
            Properties.Add("dispidTaskDelegator", "PidLidTaskAssigner");
            Properties.Add("dispidTaskDelegValue", "PidLidTaskAcceptanceState");
            Properties.Add("dispidTaskDueDate", "PidLidTaskDueDate");
            Properties.Add("dispidTaskEstimatedEffort", "PidLidTaskEstimatedEffort");
            Properties.Add("dispidTaskFCreator", "PidLidTaskFCreator");
            Properties.Add("dispidTaskFFixOffline", "PidLidTaskFFixOffline");
            Properties.Add("dispidTaskFRecur", "PidLidTaskFRecurring");
            Properties.Add("dispidTaskGlobalObjId", "PidLidTaskGlobalId");
            Properties.Add("dispidTaskHistory", "PidLidTaskHistory");
            Properties.Add("dispidTaskLastDelegate", "PidLidTaskLastDelegate");
            Properties.Add("dispidTaskLastUpdate", "PidLidTaskLastUpdate");
            Properties.Add("dispidTaskLastUser", "PidLidTaskLastUser");
            Properties.Add("dispidTaskMode", "PidLidTaskMode");
            Properties.Add("dispidTaskMultRecips", "PidLidTaskMultipleRecipients");
            Properties.Add("dispidTaskMyDelegators", "PidLidTaskAssigners");
            Properties.Add("dispidTaskOrdinal", "PidLidTaskOrdinal");
            Properties.Add("dispidTaskOwner", "PidLidTaskOwner");
            Properties.Add("dispidTaskOwnership", "PidLidTaskOwnership");
            Properties.Add("dispidTaskRecur", "PidLidTaskRecurrence");
            Properties.Add("dispidTaskResetReminder", "PidLidTaskResetReminder");
            Properties.Add("dispidTaskSOC", "PidLidTaskStatusOnComplete");
            Properties.Add("dispidTaskStartDate", "PidLidTaskStartDate");
            Properties.Add("dispidTaskState", "PidLidTaskState");
            Properties.Add("dispidTaskStatus", "PidLidTaskStatus");
            Properties.Add("dispidTaskUpdates", "PidLidTaskUpdates");
            Properties.Add("dispidTaskVersion", "PidLidTaskVersion");
            Properties.Add("dispidTimeZoneDesc", "PidLidTimeZoneDescription");
            Properties.Add("dispidTimeZoneStruct", "PidLidTimeZoneStruct");
            Properties.Add("dispidToAttendeesString", "PidLidToAttendeesString");
            Properties.Add("dispidToDoOrdinalDate", "PidLidToDoOrdinalDate");
            Properties.Add("dispidToDoSubOrdinal", "PidLidToDoSubOrdinal");
            Properties.Add("dispidToDoTitle", "PidLidToDoTitle");
            Properties.Add("dispidUseTNEF", "PidLidUseTnef");
            Properties.Add("dispidValidFlagStringProof", "PidLidValidFlagStringProof");
            Properties.Add("dispidVerbResponse", "PidLidVerbResponse");
            Properties.Add("dispidVerbStream", "PidLidVerbStream");
            Properties.Add("dispidWorkAddress", "PidLidWorkAddress");
            Properties.Add("dispidWorkAddressCity", "PidLidWorkAddressCity");
            Properties.Add("dispidWorkAddressCountry", "PidLidWorkAddressCountry");
            Properties.Add("dispidWorkAddressCountryCode", "PidLidWorkAddressCountryCode");
            Properties.Add("dispidWorkAddressPostalCode", "PidLidWorkAddressPostalCode");
            Properties.Add("dispidWorkAddressPostOfficeBox", "PidLidWorkAddressPostOfficeBox");
            Properties.Add("dispidWorkAddressState", "PidLidWorkAddressState");
            Properties.Add("dispidWorkAddressStreet", "PidLidWorkAddressStreet");
            Properties.Add("dispidYomiCompanyName", "PidLidYomiCompanyName");
            Properties.Add("dispidYomiFirstName", "PidLidYomiFirstName");
            Properties.Add("dispidYomiLastName", "PidLidYomiLastName");
            Properties.Add("LID_ATTENDEE_CRITICAL_CHANGE", "PidLidAttendeeCriticalChange");
            Properties.Add("LID_CALENDAR_TYPE", "PidLidCalendarType");
            Properties.Add("LID_GLOBAL_OBJID", "PidLidGlobalObjectId");
            Properties.Add("LID_IS_EXCEPTION", "PidLidIsException");
            Properties.Add("LID_IS_RECURRING", "PidLidIsRecurring");
            Properties.Add("LID_IS_SILENT", "PidLidIsSilent");
            Properties.Add("LID_OWNER_CRITICAL_CHANGE", "PidLidOwnerCriticalChange");
            Properties.Add("LID_TIME_ZONE", "PidLidTimeZone");
            Properties.Add("LID_WHERE", "PidLidWhere");
            Properties.Add("PR_EMS_AB_SERVER_W", "PidTagEmsAbServer");
            Properties.Add("PR_END_DATE", "PidTagEndDate");
            Properties.Add("PR_ENTRYID", "PidTagEntryId");
            Properties.Add("PR_EXCEPTION_ENDTIME", "PidTagExceptionEndTime");
            Properties.Add("PR_EXCEPTION_REPLACETIME", "PidTagExceptionReplaceTime");
            Properties.Add("PR_EXCEPTION_STARTTIME", "PidTagExceptionStartTime");
            Properties.Add("PR_EXPIRY_NUMBER", "PidTagExpiryNumber");
            Properties.Add("PR_EXPIRY_TIME", "PidTagExpiryTime");
            Properties.Add("PR_EXPIRY_UNITS", "PidTagExpiryUnits");
            Properties.Add("PR_EXPLICIT_CONVERSION", "PidTagExplicitConversion");
            Properties.Add("PR_EXTENDED_FOLDER_FLAGS", "PidTagExtendedFolderFlags");
            Properties.Add("PR_EXTENDED_RULE_MSG_ACTIONS", "PidTagExtendedRuleMessageActions");
            Properties.Add("PR_EXTENDED_RULE_MSG_CONDITION", "PidTagExtendedRuleMessageCondition");
            Properties.Add("PR_EXTENDED_RULE_SIZE_LIMIT", "PidTagExtendedRuleSizeLimit");
            Properties.Add("PR_FINDER_ENTRYID", "PidTagFinderEntryId");
            Properties.Add("PR_FLAG_COMPLETE_TIME", "PidTagFlagCompleteTime");
            Properties.Add("PR_FLAG_STATUS", "PidTagFlagStatus");
            Properties.Add("PR_FOLDER_ASSOCIATED_CONTENTS", "PidTagFolderAssociatedContents");
            Properties.Add("PR_FOLDER_TYPE", "PidTagFolderType");
            Properties.Add("PR_FOLLOWUP_ICON", "PidTagFollowupIcon");
            Properties.Add("PR_FORM_CATEGORY_A", "PidTagFormCategory");
            Properties.Add("PR_FORM_CATEGORY_SUB_A", "PidTagFormCategorySub");
            Properties.Add("PR_FORM_CATEGORY_SUB_W", "PidTagFormCategorySub");
            Properties.Add("PR_FORM_CATEGORY_SUB", "PidTagFormCategorySub");
            Properties.Add("PR_FORM_CATEGORY_W", "PidTagFormCategory");
            Properties.Add("PR_FORM_CATEGORY", "PidTagFormCategory");
            Properties.Add("PR_FORM_CLSID", "PidTagFormClassId");
            Properties.Add("PR_FORM_CONTACT_NAME_A", "PidTagFormContactName");
            Properties.Add("PR_FORM_CONTACT_NAME_W", "PidTagFormContactName");
            Properties.Add("PR_FORM_CONTACT_NAME", "PidTagFormContactName");
            Properties.Add("PR_FORM_DESIGNER_GUID", "PidTagFormDesignerGuid");
            Properties.Add("PR_FORM_DESIGNER_NAME_A", "PidTagFormDesignerName");
            Properties.Add("PR_FORM_DESIGNER_NAME_W", "PidTagFormDesignerName");
            Properties.Add("PR_FORM_DESIGNER_NAME", "PidTagFormDesignerName");
            Properties.Add("PR_FORM_HIDDEN", "PidTagFormHidden");
            Properties.Add("PR_FORM_HOST_MAP", "PidTagFormHostMap");
            Properties.Add("PR_FORM_MESSAGE_BEHAVIOR", "PidTagFormMessageBehavior");
            Properties.Add("PR_FORM_VERSION_A", "PidTagFormVersion");
            Properties.Add("PR_FORM_VERSION_W", "PidTagFormVersion");
            Properties.Add("PR_FORM_VERSION", "PidTagFormVersion");
            Properties.Add("PR_FREEBUSY_COUNT_MONTHS", "PidTagFreeBusyCountMonths");
            Properties.Add("PR_FREEBUSY_ENTRYIDS", "PidTagFreeBusyEntryIds");
            Properties.Add("PR_FREEBUSY_PUBLISH_END", "PidTagFreeBusyPublishEnd");
            Properties.Add("PR_FREEBUSY_PUBLISH_START", "PidTagFreeBusyPublishStart");
            Properties.Add("PR_FREEBUSY_RANGE_TIMESTAMP", "PidTagFreeBusyRangeTimestamp");
            Properties.Add("PR_FTP_SITE_A", "PidTagFtpSite");
            Properties.Add("PR_FTP_SITE_W", "PidTagFtpSite");
            Properties.Add("PR_FTP_SITE", "PidTagFtpSite");
            Properties.Add("PR_GENDER", "PidTagGender");
            Properties.Add("PR_GENERATION_A", "PidTagGeneration");
            Properties.Add("PR_GENERATION_W", "PidTagGeneration");
            Properties.Add("PR_GENERATION", "PidTagGeneration");
            Properties.Add("PR_GIVEN_NAME_A", "PidTagGivenName");
            Properties.Add("PR_GIVEN_NAME_W", "PidTagGivenName");
            Properties.Add("PR_GIVEN_NAME", "PidTagGivenName");
            Properties.Add("PR_GOVERNMENT_ID_NUMBER_A", "PidTagGovernmentIdNumber");
            Properties.Add("PR_GOVERNMENT_ID_NUMBER_W", "PidTagGovernmentIdNumber");
            Properties.Add("PR_GOVERNMENT_ID_NUMBER", "PidTagGovernmentIdNumber");
            Properties.Add("PR_HAS_DAMS", "PidTagHasDeferredActionMessages");
            Properties.Add("PR_HASATTACH", "PidTagHasAttachments");
            Properties.Add("PR_HOBBIES_A", "PidTagHobbies");
            Properties.Add("PR_HOBBIES_W", "PidTagHobbies");
            Properties.Add("PR_HOBBIES", "PidTagHobbies");
            Properties.Add("PR_HOME_ADDRESS_CITY_A", "PidTagHomeAddressCity");
            Properties.Add("PR_HOME_ADDRESS_CITY_W", "PidTagHomeAddressCity");
            Properties.Add("PR_HOME_ADDRESS_CITY", "PidTagHomeAddressCity");
            Properties.Add("PR_HOME_ADDRESS_COUNTRY_A", "PidTagHomeAddressCountry");
            Properties.Add("PR_HOME_ADDRESS_COUNTRY_W", "PidTagHomeAddressCountry");
            Properties.Add("PR_HOME_ADDRESS_COUNTRY", "PidTagHomeAddressCountry");
            Properties.Add("PR_HOME_ADDRESS_POST_OFFICE_BOX_A", "PidTagHomeAddressPostOfficeBox");
            Properties.Add("PR_HOME_ADDRESS_POST_OFFICE_BOX_W", "PidTagHomeAddressPostOfficeBox");
            Properties.Add("PR_HOME_ADDRESS_POST_OFFICE_BOX", "PidTagHomeAddressPostOfficeBox");
            Properties.Add("PR_HOME_ADDRESS_POSTAL_CODE_A", "PidTagHomeAddressPostalCode");
            Properties.Add("PR_HOME_ADDRESS_POSTAL_CODE_W", "PidTagHomeAddressPostalCode");
            Properties.Add("PR_HOME_ADDRESS_POSTAL_CODE", "PidTagHomeAddressPostalCode");
            Properties.Add("PR_HOME_ADDRESS_STATE_OR_PROVINCE_A", "PidTagHomeAddressStateOrProvince");
            Properties.Add("PR_HOME_ADDRESS_STATE_OR_PROVINCE_W", "PidTagHomeAddressStateOrProvince");
            Properties.Add("PR_HOME_ADDRESS_STATE_OR_PROVINCE", "PidTagHomeAddressStateOrProvince");
            Properties.Add("PR_HOME_ADDRESS_STREET_A", "PidTagHomeAddressStreet");
            Properties.Add("PR_HOME_ADDRESS_STREET_W", "PidTagHomeAddressStreet");
            Properties.Add("PR_HOME_ADDRESS_STREET", "PidTagHomeAddressStreet");
            Properties.Add("PR_HOME_FAX_NUMBER_A", "PidTagHomeFaxNumber");
            Properties.Add("PR_HOME_FAX_NUMBER_W", "PidTagHomeFaxNumber");
            Properties.Add("PR_HOME_FAX_NUMBER", "PidTagHomeFaxNumber");
            Properties.Add("PR_HOME_TELEPHONE_NUMBER_A", "PidTagHomeTelephoneNumber");
            Properties.Add("PR_HOME_TELEPHONE_NUMBER_W", "PidTagHomeTelephoneNumber");
            Properties.Add("PR_HOME_TELEPHONE_NUMBER", "PidTagHomeTelephoneNumber");
            Properties.Add("PR_HOME2_TELEPHONE_NUMBER_A_MV", "PidTagHome2TelephoneNumbers");
            Properties.Add("PR_HOME2_TELEPHONE_NUMBER_A", "PidTagHome2TelephoneNumber");
            Properties.Add("PR_HOME2_TELEPHONE_NUMBER_W", "PidTagHome2TelephoneNumber");
            Properties.Add("PR_HOME2_TELEPHONE_NUMBER", "PidTagHome2TelephoneNumber");
            Properties.Add("PR_HTML", "PidTagHtml");
            Properties.Add("PR_ICON_INDEX", "PidTagIconIndex");
            Properties.Add("PR_ICON", "PidTagIcon");
            Properties.Add("PR_IDENTITY_DISPLAY_A", "PidTagIdentityDisplay");
            Properties.Add("PR_IDENTITY_DISPLAY_W", "PidTagIdentityDisplay");
            Properties.Add("PR_IDENTITY_DISPLAY", "PidTagIdentityDisplay");
            Properties.Add("PR_IDENTITY_ENTRYID", "PidTagIdentityEntryId");
            Properties.Add("PR_IDENTITY_SEARCH_KEY", "PidTagIdentitySearchKey");
            Properties.Add("PR_IMPLICIT_CONVERSION_PROHIBITED", "PidTagImplicitConversionProhibited");
            Properties.Add("PR_IMPORTANCE", "PidTagImportance");
            Properties.Add("PR_IN_CONFLICT", "PidTagInConflict");
            Properties.Add("PR_IN_REPLY_TO_ID_A", "PidTagInReplyToId");
            Properties.Add("PR_IN_REPLY_TO_ID_W", "PidTagInReplyToId");
            Properties.Add("PR_IN_REPLY_TO_ID", "PidTagInReplyToId");
            Properties.Add("PR_INCOMPLETE_COPY", "PidTagIncompleteCopy");
            Properties.Add("PR_INETMAIL_OVERRIDE_FORMAT", "PidTagInternetMailOverrideFormat");
            Properties.Add("PR_INFERENCES_ENABLED", "PidTagInferenceEnabled");
            Properties.Add("PR_INITIAL_DETAILS_PANE", "PidTagInitialDetailsPane");
            Properties.Add("PR_INITIALS_A", "PidTagInitials");
            Properties.Add("PR_INITIALS_W", "PidTagInitials");
            Properties.Add("PR_INITIALS", "PidTagInitials");
            Properties.Add("PR_INSTANCE_KEY", "PidTagInstanceKey");
            Properties.Add("PR_INTERNET_APPROVED", "PidTagInternetApproved");
            Properties.Add("PR_INTERNET_APPROVED_A", "PidTagInternetApproved");
            Properties.Add("PR_INTERNET_APPROVED_W", "PidTagInternetApproved");
            Properties.Add("PR_INTERNET_ARTICLE_NUMBER", "PidTagInternetArticleNumber");
            Properties.Add("PR_INTERNET_CONTROL", "PidTagInternetControl");
            Properties.Add("PR_INTERNET_CONTROL_A", "PidTagInternetControl");
            Properties.Add("PR_INTERNET_CONTROL_W", "PidTagInternetControl");
            Properties.Add("PR_INTERNET_CPID", "PidTagInternetCodepage");
            Properties.Add("PR_INTERNET_DISTRIBUTION", "PidTagInternetDistribution");
            Properties.Add("PR_INTERNET_DISTRIBUTION_A", "PidTagInternetDistribution");
            Properties.Add("PR_INTERNET_DISTRIBUTION_W", "PidTagInternetDistribution");
            Properties.Add("PR_INTERNET_FOLLOWUP_TO", "PidTagInternetFollowupTo");
            Properties.Add("PR_INTERNET_FOLLOWUP_TO_A", "PidTagInternetFollowupTo");
            Properties.Add("PR_INTERNET_FOLLOWUP_TO_W", "PidTagInternetFollowupTo");
            Properties.Add("PR_INTERNET_LINES", "PidTagInternetLines");
            Properties.Add("PR_INTERNET_MESSAGE_ID_A", "PidTagInternetMessageId");
            Properties.Add("PR_INTERNET_MESSAGE_ID_W", "PidTagInternetMessageId");
            Properties.Add("PR_INTERNET_MESSAGE_ID", "PidTagInternetMessageId");
            Properties.Add("PR_INTERNET_NNTP_PATH", "PidTagInternetNntpPath");
            Properties.Add("PR_INTERNET_NNTP_PATH_A", "PidTagInternetNntpPath");
            Properties.Add("PR_INTERNET_NNTP_PATH_W", "PidTagInternetNntpPath");
            Properties.Add("PR_INTERNET_ORGANIZATION", "PidTagInternetOrganization");
            Properties.Add("PR_INTERNET_ORGANIZATION_A", "PidTagInternetOrganization");
            Properties.Add("PR_INTERNET_ORGANIZATION_W", "PidTagInternetOrganization");
            Properties.Add("PR_INTERNET_REFERENCES_A", "PidTagInternetReferences");
            Properties.Add("PR_INTERNET_REFERENCES_W", "PidTagInternetReferences");
            Properties.Add("PR_INTERNET_REFERENCES", "PidTagInternetReferences");
            Properties.Add("PR_INTERNET_RETURN_PATH_A", "PidTagInternetReturnPath");
            Properties.Add("PR_INTERNET_RETURN_PATH_W", "PidTagInternetReturnPath");
            Properties.Add("PR_INTERNET_RETURN_PATH", "PidTagInternetReturnPath");
            Properties.Add("PR_IPM_APPOINTMENT_ENTRYID", "PidTagIpmAppointmentEntryId");
            Properties.Add("PR_IPM_CONTACT_ENTRYID", "PidTagIpmContactEntryId");
            Properties.Add("PR_IPM_DRAFTS_ENTRYID", "PidTagIpmDraftsEntryId");
            Properties.Add("PR_IPM_JOURNAL_ENTRYID", "PidTagIpmJournalEntryId");
            Properties.Add("PR_IPM_NOTE_ENTRYID", "PidTagIpmNoteEntryId");
            Properties.Add("PR_IPM_OUTBOX_ENTRYID", "PidTagIpmOutboxEntryId");
            Properties.Add("PR_IPM_RETURN_REQUESTED", "PidTagIpmReturnRequested");
            Properties.Add("PR_IPM_SENTMAIL_ENTRYID", "PidTagIpmSentMailEntryId");
            Properties.Add("PR_IPM_SUBTREE_ENTRYID", "PidTagIpmSubtreeEntryId");
            Properties.Add("PR_IPM_TASK_ENTRYID", "PidTagIpmTaskEntryId");
            Properties.Add("PR_IPM_WASTEBASKET_ENTRYID", "PidTagIpmWastebasketEntryId");
            Properties.Add("PR_ISDN_NUMBER_A", "PidTagIsdnNumber");
            Properties.Add("PR_ISDN_NUMBER_W", "PidTagIsdnNumber");
            Properties.Add("PR_ISDN_NUMBER", "PidTagIsdnNumber");
            Properties.Add("PR_ITEM_TMPFLAGS", "PidTagItemTemporaryflags");
            Properties.Add("PR_JUNK_ADD_RECIPS_TO_SSL", "PidTagJunkAddRecipientsToSafeSendersList");
            Properties.Add("PR_JUNK_INCLUDE_CONTACTS", "PidTagJunkIncludeContacts");
            Properties.Add("PR_JUNK_PERMANENTLY_DELETE", "PidTagJunkPermanentlyDelete");
            Properties.Add("PR_JUNK_PHISHING_ENABLE_LINKS", "PidTagJunkPhishingEnableLinks");
            Properties.Add("PR_JUNK_THRESHOLD", "PidTagJunkThreshold");
            Properties.Add("PR_KEYWORD_A", "PidTagKeyword");
            Properties.Add("PR_KEYWORD_W", "PidTagKeyword");
            Properties.Add("PR_KEYWORD", "PidTagKeyword");
            Properties.Add("PR_LANGUAGE_A", "PidTagLanguage");
            Properties.Add("PR_LANGUAGE_W", "PidTagLanguage");
            Properties.Add("PR_LANGUAGE", "PidTagLanguage");
            Properties.Add("PR_LANGUAGES_A", "PidTagLanguages");
            Properties.Add("PR_LANGUAGES_W", "PidTagLanguages");
            Properties.Add("PR_LANGUAGES", "PidTagLanguages");
            Properties.Add("PR_LAST_MODIFICATION_TIME", "PidTagLastModificationTime");
            Properties.Add("PR_LAST_VERB_EXECUTED", "PidTagLastVerbExecuted");
            Properties.Add("PR_LAST_VERB_EXECUTION_TIME", "PidTagLastVerbExecutionTime");
            Properties.Add("PR_LATEST_DELIVERY_TIME", "PidTagLatestDeliveryTime");
            Properties.Add("PR_LIST_HELP_A", "PidTagListHelp");
            Properties.Add("PR_LIST_HELP_W", "PidTagListHelp");
            Properties.Add("PR_LIST_HELP", "PidTagListHelp");
            Properties.Add("PR_LIST_SUBSCRIBE_A", "PidTagListSubscribe");
            Properties.Add("PR_LIST_SUBSCRIBE_W", "PidTagListSubscribe");
            Properties.Add("PR_LIST_SUBSCRIBE", "PidTagListSubscribe");
            Properties.Add("PR_LIST_UNSUBSCRIBE_A", "PidTagListUnsubscribe");
            Properties.Add("PR_LIST_UNSUBSCRIBE_W", "PidTagListUnsubscribe");
            Properties.Add("PR_LIST_UNSUBSCRIBE", "PidTagListUnsubscribe");
            Properties.Add("PR_LOCALE_ID", "PidTagLocaleId");
            Properties.Add("PR_LOCALITY_A", "PidTagLocality");
            Properties.Add("PR_LOCALITY_W", "PidTagLocality");
            Properties.Add("PR_LOCALITY", "PidTagLocality");
            Properties.Add("PR_LOCATION_A", "PidTagLocation");
            Properties.Add("PR_LOCATION_W", "PidTagLocation");
            Properties.Add("PR_LOCATION", "PidTagLocation");
            Properties.Add("PR_MAIL_PERMISSION", "PidTagMailPermission");
            Properties.Add("PR_MANAGER_NAME_A", "PidTagManagerName");
            Properties.Add("PR_MANAGER_NAME_W", "PidTagManagerName");
            Properties.Add("PR_MANAGER_NAME", "PidTagManagerName");
            Properties.Add("PR_MAPPING_SIGNATURE", "PidTagMappingSignature");
            Properties.Add("PR_MDB_PROVIDER", "PidTagStoreProvider");
            Properties.Add("PR_MEMBER_ENTRYID", "PidTagMemberEntryId");
            Properties.Add("PR_MEMBER_ID", "PidTagMemberId");
            Properties.Add("PR_MEMBER_NAME", "PidTagMemberName");
            Properties.Add("PR_MEMBER_RIGHTS", "PidTagMemberRights");
            Properties.Add("PR_MESSAGE_ATTACHMENTS", "PidTagMessageAttachments");
            Properties.Add("PR_MESSAGE_CC_ME", "PidTagMessageCcMe");
            Properties.Add("PR_MESSAGE_CLASS_A", "PidTagMessageClass");
            Properties.Add("PR_MESSAGE_CLASS_W", "PidTagMessageClass");
            Properties.Add("PR_MESSAGE_CLASS", "PidTagMessageClass");
            Properties.Add("PR_MESSAGE_CODEPAGE", "PidTagMessageCodepage");
            Properties.Add("PR_MESSAGE_DELIVERY_ID", "PidTagMessageDeliveryId");
            Properties.Add("PR_MESSAGE_DELIVERY_TIME", "PidTagMessageDeliveryTime");
            Properties.Add("PR_MESSAGE_DOWNLOAD_TIME", "PidTagMessageDownloadTime");
            Properties.Add("PR_MESSAGE_FLAGS", "PidTagMessageFlags");
            Properties.Add("PR_MESSAGE_LOCALE_ID", "PidTagMessageLocaleId");
            Properties.Add("PR_MESSAGE_RECIP_ME", "PidTagMessageRecipientMe");
            Properties.Add("PR_MESSAGE_RECIPIENTS", "PidTagMessageRecipients");
            Properties.Add("PR_MESSAGE_SECURITY_LABEL", "PidTagMessageSecurityLabel");
            Properties.Add("PR_MESSAGE_SIZE_EXTENDED", "PidTagMessageSizeExtended");
            Properties.Add("PR_MESSAGE_SIZE", "PidTagMessageSize");
            Properties.Add("PR_MESSAGE_SUBMISSION_ID", "PidTagMessageSubmissionId");
            Properties.Add("PR_MESSAGE_TO_ME", "PidTagMessageToMe");
            Properties.Add("PR_MHS_COMMON_NAME_A", "PidTagMessageHandlingSystemCommonName");
            Properties.Add("PR_MHS_COMMON_NAME_W", "PidTagMessageHandlingSystemCommonName");
            Properties.Add("PR_MHS_COMMON_NAME", "PidTagMessageHandlingSystemCommonName");
            Properties.Add("PR_MIDDLE_NAME_A", "PidTagMiddleName");
            Properties.Add("PR_MIDDLE_NAME_W", "PidTagMiddleName");
            Properties.Add("PR_MIDDLE_NAME", "PidTagMiddleName");
            Properties.Add("PR_MINI_ICON", "PidTagMiniIcon");
            Properties.Add("PR_MOBILE_TELEPHONE_NUMBER_A", "PidTagMobileTelephoneNumber");
            Properties.Add("PR_MOBILE_TELEPHONE_NUMBER_W", "PidTagMobileTelephoneNumber");
            Properties.Add("PR_MOBILE_TELEPHONE_NUMBER", "PidTagMobileTelephoneNumber");
            Properties.Add("PR_MSG_EDITOR_FORMAT", "PidTagMessageEditorFormat");
            Properties.Add("PR_MSG_STATUS", "PidTagMessageStatus");
            Properties.Add("PR_NDR_DIAG_CODE", "PidTagNonDeliveryReportDiagCode");
            Properties.Add("PR_NDR_FROM_ENTRYID", "PidTagNonDeliveryReportFromEntryId");
            Properties.Add("PR_NDR_FROM_NAME", "PidTagNonDeliveryReportFromName");
            Properties.Add("PR_NDR_FROM_SEARCH_KEY", "PidTagNonDeliveryReportFromSearchKey");
            Properties.Add("PR_NDR_REASON_CODE", "PidTagNonDeliveryReportReasonCode");
            Properties.Add("PR_NEXT_SEND_ACCT", "PidTagNextSendAcct");
            Properties.Add("PR_NICKNAME_A", "PidTagNickname");
            Properties.Add("PR_NICKNAME_W", "PidTagNickname");
            Properties.Add("PR_NICKNAME", "PidTagNickname");
            Properties.Add("PR_NON_IPM_SUBTREE_ENTRYID", "PidTagNonIpmSubtreeEntryId");
            Properties.Add("PR_NON_RECEIPT_NOTIFICATION_REQUESTED", "PidTagNonReceiptNotificationRequested");
            Properties.Add("PR_NON_RECEIPT_REASON", "PidTagNonReceiptReason");
            Properties.Add("PR_NORMALIZED_SUBJECT_A", "PidTagNormalizedSubject");
            Properties.Add("PR_NORMALIZED_SUBJECT_W", "PidTagNormalizedSubject");
            Properties.Add("PR_NORMALIZED_SUBJECT", "PidTagNormalizedSubject");
            Properties.Add("PR_OBJECT_TYPE", "PidTagObjectType");
            Properties.Add("PR_OBSOLETED_IPMS", "PidTagObsoletedMessageIds");
            Properties.Add("PR_OFFICE_LOCATION_A", "PidTagOfficeLocation");
            Properties.Add("PR_OFFICE_LOCATION_W", "PidTagOfficeLocation");
            Properties.Add("PR_OFFICE_LOCATION", "PidTagOfficeLocation");
            Properties.Add("PR_OFFICE_TELEPHONE_NUMBER", "PidTagBusinessTelephoneNumber");
            Properties.Add("PR_OFFICE_TELEPHONE_NUMBER_W", "PidTagBusinessTelephoneNumber");
            Properties.Add("PR_OFFICE2_TELEPHONE_NUMBER", "PidTagBusiness2TelephoneNumber");
            Properties.Add("PR_ORDINAL_MOST", "PidTagOrdinalMost");
            Properties.Add("PR_ORG_EMAIL_ADDRESS", "PidTagOrgEmailAddress");
            Properties.Add("PR_ORGANIZATIONAL_ID_NUMBER_A", "PidTagOrganizationalIdNumber");
            Properties.Add("PR_ORGANIZATIONAL_ID_NUMBER_W", "PidTagOrganizationalIdNumber");
            Properties.Add("PR_ORGANIZATIONAL_ID_NUMBER", "PidTagOrganizationalIdNumber");
            Properties.Add("PR_ORIG_MESSAGE_CLASS_A", "PidTagOriginalMessageClass");
            Properties.Add("PR_ORIG_MESSAGE_CLASS_W", "PidTagOriginalMessageClass");
            Properties.Add("PR_ORIG_MESSAGE_CLASS", "PidTagOriginalMessageClass");
            Properties.Add("PR_ORIGIN_CHECK", "PidTagOriginCheck");
            Properties.Add("PR_ORIGINAL_AUTHOR_ADDRTYPE_A", "PidTagOriginalAuthorAddressType");
            Properties.Add("PR_ORIGINAL_AUTHOR_ADDRTYPE_W", "PidTagOriginalAuthorAddressType");
            Properties.Add("PR_ORIGINAL_AUTHOR_ADDRTYPE", "PidTagOriginalAuthorAddressType");
            Properties.Add("PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_A", "PidTagOriginalAuthorEmailAddress");
            Properties.Add("PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_W", "PidTagOriginalAuthorEmailAddress");
            Properties.Add("PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS", "PidTagOriginalAuthorEmailAddress");
            Properties.Add("PR_ORIGINAL_AUTHOR_ENTRYID", "PidTagOriginalAuthorEntryId");
            Properties.Add("PR_ORIGINAL_AUTHOR_NAME_A", "PidTagOriginalAuthorName");
            Properties.Add("PR_ORIGINAL_AUTHOR_NAME_W", "PidTagOriginalAuthorName");
            Properties.Add("PR_ORIGINAL_AUTHOR_NAME", "PidTagOriginalAuthorName");
            Properties.Add("PR_ORIGINAL_AUTHOR_SEARCH_KEY", "PidTagOriginalAuthorSearchKey");
            Properties.Add("PR_ORIGINAL_DELIVERY_TIME", "PidTagOriginalDeliveryTime");
            Properties.Add("PR_ORIGINAL_DISPLAY_BCC_A", "PidTagOriginalDisplayBcc");
            Properties.Add("PR_ORIGINAL_DISPLAY_BCC_W", "PidTagOriginalDisplayBcc");
            Properties.Add("PR_ORIGINAL_DISPLAY_BCC", "PidTagOriginalDisplayBcc");
            Properties.Add("PR_ORIGINAL_DISPLAY_CC_A", "PidTagOriginalDisplayCc");
            Properties.Add("PR_ORIGINAL_DISPLAY_CC_W", "PidTagOriginalDisplayCc");
            Properties.Add("PR_ORIGINAL_DISPLAY_CC", "PidTagOriginalDisplayCc");
            Properties.Add("PR_ORIGINAL_DISPLAY_NAME_A", "PidTagOriginalDisplayName");
            Properties.Add("PR_ORIGINAL_DISPLAY_NAME_W", "PidTagOriginalDisplayName");
            Properties.Add("PR_ORIGINAL_DISPLAY_NAME", "PidTagOriginalDisplayName");
            Properties.Add("PR_ORIGINAL_DISPLAY_TO_A", "PidTagOriginalDisplayTo");
            Properties.Add("PR_ORIGINAL_DISPLAY_TO_W", "PidTagOriginalDisplayTo");
            Properties.Add("PR_ORIGINAL_DISPLAY_TO", "PidTagOriginalDisplayTo");
            Properties.Add("PR_ORIGINAL_EITS", "PidTagOriginalEits");
            Properties.Add("PR_ORIGINAL_ENTRYID", "PidTagOriginalEntryId");
            Properties.Add("PR_ORIGINAL_SEARCH_KEY", "PidTagOriginalSearchKey");
            Properties.Add("PR_ORIGINAL_SENDER_ADDRTYPE_A", "PidTagOriginalSenderAddressType");
            Properties.Add("PR_ORIGINAL_SENDER_ADDRTYPE_W", "PidTagOriginalSenderAddressType");
            Properties.Add("PR_ORIGINAL_SENDER_ADDRTYPE", "PidTagOriginalSenderAddressType");
            Properties.Add("PR_ORIGINAL_SENDER_EMAIL_ADDRESS_A", "PidTagOriginalSenderEmailAddress");
            Properties.Add("PR_ORIGINAL_SENDER_EMAIL_ADDRESS_W", "PidTagOriginalSenderEmailAddress");
            Properties.Add("PR_ORIGINAL_SENDER_EMAIL_ADDRESS", "PidTagOriginalSenderEmailAddress");
            Properties.Add("PR_ORIGINAL_SENDER_ENTRYID", "PidTagOriginalSenderEntryId");
            Properties.Add("PR_ORIGINAL_SENDER_NAME_A", "PidTagOriginalSenderName");
            Properties.Add("PR_ORIGINAL_SENDER_NAME_W", "PidTagOriginalSenderName");
            Properties.Add("PR_ORIGINAL_SENDER_NAME", "PidTagOriginalSenderName");
            Properties.Add("PR_ORIGINAL_SENDER_SEARCH_KEY", "PidTagOriginalSenderSearchKey");
            Properties.Add("PR_ORIGINAL_SENSITIVITY", "PidTagOriginalSensitivity");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_A", "PidTagOriginalSentRepresentingAddressType");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_W", "PidTagOriginalSentRepresentingAddressType");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE", "PidTagOriginalSentRepresentingAddressType");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_A", "PidTagOriginalSentRepresentingEmailAddress");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_W", "PidTagOriginalSentRepresentingEmailAddress");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS", "PidTagOriginalSentRepresentingEmailAddress");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_ENTRYID", "PidTagOriginalSentRepresentingEntryId");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_NAME_A", "PidTagOriginalSentRepresentingName");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_NAME_W", "PidTagOriginalSentRepresentingName");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_NAME", "PidTagOriginalSentRepresentingName");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY_A", "PidTagOriginalSentRepresentingSearchKey");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY_W", "PidTagOriginalSentRepresentingSearchKey");
            Properties.Add("PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY", "PidTagOriginalSentRepresentingSearchKey");
            Properties.Add("PR_ORIGINAL_SUBJECT_A", "PidTagOriginalSubject");
            Properties.Add("PR_ORIGINAL_SUBJECT_W", "PidTagOriginalSubject");
            Properties.Add("PR_ORIGINAL_SUBJECT", "PidTagOriginalSubject");
            Properties.Add("PR_ORIGINAL_SUBMIT_TIME", "PidTagOriginalSubmitTime");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_A", "PidTagOriginallyIntendedRecipAddrtype");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_W", "PidTagOriginallyIntendedRecipAddrtype");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE", "PidTagOriginallyIntendedRecipAddrtype");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_A", "PidTagOriginallyIntendedRecipEmailAddress");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_W", "PidTagOriginallyIntendedRecipEmailAddress");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS", "PidTagOriginallyIntendedRecipEmailAddress");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIP_ENTRYID", "PidTagOriginallyIntendedRecipEntryId");
            Properties.Add("PR_ORIGINALLY_INTENDED_RECIPIENT_NAME", "PidTagOriginallyIntendedRecipientName");
            Properties.Add("PR_ORIGINATING_MTA_CERTIFICATE", "PidTagOriginatingMtaCertificate");
            Properties.Add("PR_ORIGINATOR_AND_DL_EXPANSION_HISTORY",
                "PidTagOriginatorAndDistributionListExpansionHistory");
            Properties.Add("PR_ORIGINATOR_CERTIFICATE", "PidTagOriginatorCertificate");
            Properties.Add("PR_ORIGINATOR_DELIVERY_REPORT_REQUESTED", "PidTagOriginatorDeliveryReportRequested");
            Properties.Add("PR_ORIGINATOR_NON_DELIVERY_REPORT_REQUESTED", "PidTagOriginatorNonDeliveryReportRequested");
            Properties.Add("PR_ORIGINATOR_REQUESTED_ALTERNATE_RECIPIENT", "PidTagOriginatorRequestedAlternateRecipient");
            Properties.Add("PR_ORIGINATOR_RETURN_ADDRESS", "PidTagOriginatorReturnAddress");
            Properties.Add("PR_OTHER_ADDRESS_CITY_A", "PidTagOtherAddressCity");
            Properties.Add("PR_OTHER_ADDRESS_CITY_W", "PidTagOtherAddressCity");
            Properties.Add("PR_OTHER_ADDRESS_CITY", "PidTagOtherAddressCity");
            Properties.Add("PR_OTHER_ADDRESS_COUNTRY_A", "PidTagOtherAddressCountry");
            Properties.Add("PR_OTHER_ADDRESS_COUNTRY_W", "PidTagOtherAddressCountry");
            Properties.Add("PR_OTHER_ADDRESS_COUNTRY", "PidTagOtherAddressCountry");
            Properties.Add("PR_OTHER_ADDRESS_POST_OFFICE_BOX_A", "PidTagOtherAddressPostOfficeBox");
            Properties.Add("PR_OTHER_ADDRESS_POST_OFFICE_BOX_W", "PidTagOtherAddressPostOfficeBox");
            Properties.Add("PR_OTHER_ADDRESS_POST_OFFICE_BOX", "PidTagOtherAddressPostOfficeBox");
            Properties.Add("PR_OTHER_ADDRESS_POSTAL_CODE_A", "PidTagOtherAddressPostalCode");
            Properties.Add("PR_OTHER_ADDRESS_POSTAL_CODE_W", "PidTagOtherAddressPostalCode");
            Properties.Add("PR_OTHER_ADDRESS_POSTAL_CODE", "PidTagOtherAddressPostalCode");
            Properties.Add("PR_OTHER_ADDRESS_STATE_OR_PROVINCE_A", "PidTagOtherAddressStateOrProvince");
            Properties.Add("PR_OTHER_ADDRESS_STATE_OR_PROVINCE_W", "PidTagOtherAddressStateOrProvince");
            Properties.Add("PR_OTHER_ADDRESS_STATE_OR_PROVINCE", "PidTagOtherAddressStateOrProvince");
            Properties.Add("PR_OTHER_ADDRESS_STREET_A", "PidTagOtherAddressStreet");
            Properties.Add("PR_OTHER_ADDRESS_STREET_W", "PidTagOtherAddressStreet");
            Properties.Add("PR_OTHER_ADDRESS_STREET", "PidTagOtherAddressStreet");
            Properties.Add("PR_OTHER_TELEPHONE_NUMBER_A", "PidTagOtherTelephoneNumber");
            Properties.Add("PR_OTHER_TELEPHONE_NUMBER_W", "PidTagOtherTelephoneNumber");
            Properties.Add("PR_OTHER_TELEPHONE_NUMBER", "PidTagOtherTelephoneNumber");
            Properties.Add("PR_OWN_STORE_ENTRYID", "PidTagOwnStoreEntryId");
            Properties.Add("PR_OWNER_APPT_ID", "PidTagOwnerAppointmentId");
            Properties.Add("PR_PAGER_TELEPHONE_NUMBER_A", "PidTagPagerTelephoneNumber");
            Properties.Add("PR_PAGER_TELEPHONE_NUMBER_W", "PidTagPagerTelephoneNumber");
            Properties.Add("PR_PAGER_TELEPHONE_NUMBER", "PidTagPagerTelephoneNumber");
            Properties.Add("PR_PARENT_DISPLAY_A", "PidTagParentDisplay");
            Properties.Add("PR_PARENT_DISPLAY_W", "PidTagParentDisplay");
            Properties.Add("PR_PARENT_DISPLAY", "PidTagParentDisplay");
            Properties.Add("PR_PARENT_ENTRYID", "PidTagParentEntryId");
            Properties.Add("PR_PERSONAL_HOME_PAGE_A", "PidTagPersonalHomePage");
            Properties.Add("PR_PERSONAL_HOME_PAGE_W", "PidTagPersonalHomePage");
            Properties.Add("PR_PERSONAL_HOME_PAGE", "PidTagPersonalHomePage");
            Properties.Add("PR_PHYSICAL_DELIVERY_BUREAU_FAX_DELIVERY", "PidTagPhysicalDeliveryBureauFaxDelivery");
            Properties.Add("PR_PHYSICAL_DELIVERY_MODE", "PidTagPhysicalDeliveryMode");
            Properties.Add("PR_PHYSICAL_DELIVERY_REPORT_REQUEST", "PidTagPhysicalDeliveryReportRequest");
            Properties.Add("PR_PHYSICAL_FORWARDING_ADDRESS_REQUESTED", "PidTagPhysicalForwardingAddressRequested");
            Properties.Add("PR_PHYSICAL_FORWARDING_ADDRESS", "PidTagPhysicalForwardingAddress");
            Properties.Add("PR_PHYSICAL_FORWARDING_PROHIBITED", "PidTagPhysicalForwardingProhibited");
            Properties.Add("PR_PHYSICAL_RENDITION_ATTRIBUTES", "PidTagPhysicalRenditionAttributes");
            Properties.Add("PR_POST_OFFICE_BOX_A", "PidTagPostOfficeBox");
            Properties.Add("PR_POST_OFFICE_BOX_W", "PidTagPostOfficeBox");
            Properties.Add("PR_POST_OFFICE_BOX", "PidTagPostOfficeBox");
            Properties.Add("PR_POSTAL_ADDRESS_A", "PidTagPostalAddress");
            Properties.Add("PR_POSTAL_ADDRESS_W", "PidTagPostalAddress");
            Properties.Add("PR_POSTAL_ADDRESS", "PidTagPostalAddress");
            Properties.Add("PR_POSTAL_CODE_A", "PidTagPostalCode");
            Properties.Add("PR_POSTAL_CODE_W", "PidTagPostalCode");
            Properties.Add("PR_POSTAL_CODE", "PidTagPostalCode");
            Properties.Add("PR_PREFERRED_BY_NAME_A", "PidTagPreferredByName");
            Properties.Add("PR_PREFERRED_BY_NAME_W", "PidTagPreferredByName");
            Properties.Add("PR_PREFERRED_BY_NAME", "PidTagPreferredByName");
            Properties.Add("PR_PREPROCESS", "PidTagPreprocess");
            Properties.Add("PR_PRIMARY_FAX_NUMBER_A", "PidTagPrimaryFaxNumber");
            Properties.Add("PR_PRIMARY_FAX_NUMBER_W", "PidTagPrimaryFaxNumber");
            Properties.Add("PR_PRIMARY_FAX_NUMBER", "PidTagPrimaryFaxNumber");
            Properties.Add("PR_PRIMARY_SEND_ACCT", "PidTagPrimarySendAccount");
            Properties.Add("PR_PRIMARY_TELEPHONE_NUMBER_A", "PidTagPrimaryTelephoneNumber");
            Properties.Add("PR_PRIMARY_TELEPHONE_NUMBER_W", "PidTagPrimaryTelephoneNumber");
            Properties.Add("PR_PRIMARY_TELEPHONE_NUMBER", "PidTagPrimaryTelephoneNumber");
            Properties.Add("PR_PRIORITY", "PidTagPriority");
            Properties.Add("PR_PROCESSED", "PidTagProcessed");
            Properties.Add("PR_PROFESSION_A", "PidTagProfession");
            Properties.Add("PR_PROFESSION_W", "PidTagProfession");
            Properties.Add("PR_PROFESSION", "PidTagProfession");
            Properties.Add("PR_PROFILE_HOME_SERVER_FQDN", "PidTagProfileHomeServerFQDN");
            Properties.Add("PR_PROFILE_NAME_A", "PidTagProfileName");
            Properties.Add("PR_PROFILE_NAME_W", "PidTagProfileName");
            Properties.Add("PR_PROFILE_NAME", "PidTagProfileName");
            Properties.Add("PR_PROFILE_SERVER_FULL_VERSION", "PidTagProfileServerFullVersion");
            Properties.Add("PR_PROFILE_SERVER_VERSION", "PR_PROFILE_SERVER_VERSION");
            Properties.Add("PR_PROFILE_TYPE", "PidTagProfileType");
            Properties.Add("PR_PROOF_OF_DELIVERY_REQUESTED", "PidTagProofOfDeliveryRequested");
            Properties.Add("PR_PROOF_OF_DELIVERY", "PidTagProofOfDelivery");
            Properties.Add("PR_PROOF_OF_SUBMISSION_REQUESTED", "PidTagProofOfSubmissionRequested");
            Properties.Add("PR_PROOF_OF_SUBMISSION", "PidTagProofOfSubmission");
            Properties.Add("PR_PROVIDER_DISPLAY_A", "PidTagProviderDisplay");
            Properties.Add("PR_PROVIDER_DISPLAY_NAME_W", "PidTagProviderDisplayName");
            Properties.Add("PR_PROVIDER_DISPLAY_NAME", "PidTagProviderDisplayName");
            Properties.Add("PR_PROVIDER_DISPLAY_W", "PidTagProviderDisplay");
            Properties.Add("PR_PROVIDER_DISPLAY", "PidTagProviderDisplay");
            Properties.Add("PR_PROVIDER_DLL_NAME_A", "PidTagProviderDllName");
            Properties.Add("PR_PROVIDER_DLL_NAME_W", "PidTagProviderDllName");
            Properties.Add("PR_PROVIDER_DLL_NAME", "PidTagProviderDllName");
            Properties.Add("PR_PROVIDER_ICON_W", "PidTagProviderIcon");
            Properties.Add("PR_PROVIDER_ICON", "PidTagProviderIcon");
            Properties.Add("PR_PROVIDER_ITEMID", "PidTagProviderItemId");
            Properties.Add("PR_PROVIDER_ORDINAL", "PidTagProviderOrdinal");
            Properties.Add("PR_PROVIDER_PARENT_ITEMID", "PidTagProviderParentItemId");
            Properties.Add("PR_PROVIDER_SUBMIT_TIME", "PidTagProviderSubmitTime");
            Properties.Add("PR_PROVIDER_UID", "PidTagProviderUid");
            Properties.Add("PR_PST_CONFIG_FLAGS", "PidTagPstConfigurationFlags");
            Properties.Add("PR_PST_PATH", "PidTagPstPath");
            Properties.Add("PR_PST_PATH_A", "PidTagPstPath");
            Properties.Add("PR_PST_PATH_W", "PidTagPstPath");
            Properties.Add("PR_PST_PATH_HINT", "PidTagPstPathHint");
            Properties.Add("PR_PST_PATH_HINT_A", "PidTagPstPathHint");
            Properties.Add("PR_PST_PATH_HINT_W", "PidTagPstPathHint");
            Properties.Add("PR_PST_PW_SZ_NEW", "PidTagPstPasswordSzNew");
            Properties.Add("PR_PST_PW_SZ_NEW_A", "PidTagPstPasswordSzNew");
            Properties.Add("PR_PST_PW_SZ_NEW_W", "PidTagPstPasswordSzNew");
            Properties.Add("PR_PST_PW_SZ_OLD", "PidTagPstPasswordSzOld");
            Properties.Add("PR_PST_PW_SZ_OLD_A", "PidTagPstPasswordSzOld");
            Properties.Add("PR_PST_PW_SZ_OLD_W", "PidTagPstPasswordSzOld");
            Properties.Add("PR_PST_REMEMBER_PW", "PidTagPstRememberPassword");
            Properties.Add("PR_RADIO_TELEPHONE_NUMBER_A", "PidTagRadioTelephoneNumber");
            Properties.Add("PR_RADIO_TELEPHONE_NUMBER_W", "PidTagRadioTelephoneNumber");
            Properties.Add("PR_RADIO_TELEPHONE_NUMBER", "PidTagRadioTelephoneNumber");
            Properties.Add("PR_RCVD_REPRESENTING_ADDRTYPE_A", "PidTagReceivedRepresentingAddressType");
            Properties.Add("PR_RCVD_REPRESENTING_ADDRTYPE_W", "PidTagReceivedRepresentingAddressType");
            Properties.Add("PR_RCVD_REPRESENTING_ADDRTYPE", "PidTagReceivedRepresentingAddressType");
            Properties.Add("PR_RCVD_REPRESENTING_EMAIL_ADDRESS_A", "PidTagReceivedRepresentingEmailAddress");
            Properties.Add("PR_RCVD_REPRESENTING_EMAIL_ADDRESS_W", "PidTagReceivedRepresentingEmailAddress");
            Properties.Add("PR_RCVD_REPRESENTING_EMAIL_ADDRESS", "PidTagReceivedRepresentingEmailAddress");
            Properties.Add("PR_RCVD_REPRESENTING_ENTRYID", "PidTagReceivedRepresentingEntryId");
            Properties.Add("PR_RCVD_REPRESENTING_NAME_A", "PidTagReceivedRepresentingName");
            Properties.Add("PR_RCVD_REPRESENTING_NAME_W", "PidTagReceivedRepresentingName");
            Properties.Add("PR_RCVD_REPRESENTING_NAME", "PidTagReceivedRepresentingName");
            Properties.Add("PR_RCVD_REPRESENTING_SEARCH_KEY", "PidTagReceivedRepresentingSearchKey");
            Properties.Add("PR_READ_RECEIPT_ENTRYID", "PidTagReadReceiptEntryId");
            Properties.Add("PR_READ_RECEIPT_REQUESTED", "PidTagReadReceiptRequested");
            Properties.Add("PR_READ_RECEIPT_SEARCH_KEY", "PidTagReadReceiptSearchKey");
            Properties.Add("PR_READ", "PidTagRead");
            Properties.Add("PR_RECEIPT_TIME", "PidTagReceiptTime");
            Properties.Add("PR_RECEIVE_FOLDER_SETTINGS", "PidTagReceiveFolderSettings");
            Properties.Add("PR_RECEIVED_BY_ADDRTYPE_A", "PidTagReceivedByAddressType");
            Properties.Add("PR_RECEIVED_BY_ADDRTYPE_W", "PidTagReceivedByAddressType");
            Properties.Add("PR_RECEIVED_BY_ADDRTYPE", "PidTagReceivedByAddressType");
            Properties.Add("PR_RECEIVED_BY_EMAIL_ADDRESS_A", "PidTagReceivedByEmailAddress");
            Properties.Add("PR_RECEIVED_BY_EMAIL_ADDRESS_W", "PidTagReceivedByEmailAddress");
            Properties.Add("PR_RECEIVED_BY_EMAIL_ADDRESS", "PidTagReceivedByEmailAddress");
            Properties.Add("PR_RECEIVED_BY_ENTRYID", "PidTagReceivedByEntryId");
            Properties.Add("PR_RECEIVED_BY_NAME_A", "PidTagReceivedByName");
            Properties.Add("PR_RECEIVED_BY_NAME_W", "PidTagReceivedByName");
            Properties.Add("PR_RECEIVED_BY_NAME", "PidTagReceivedByName");
            Properties.Add("PR_RECEIVED_BY_SEARCH_KEY", "PidTagReceivedBySearchKey");
            Properties.Add("PR_RECIPIENT_CERTIFICATE", "PidTagRecipientCertificate");
            Properties.Add("PR_RECIPIENT_DISPLAY_NAME_W", "PidTagRecipientDisplayName");
            Properties.Add("PR_RECIPIENT_DISPLAY_NAME", "PidTagRecipientDisplayName");
            Properties.Add("PR_RECIPIENT_ENTRYID", "PidTagRecipientEntryId");
            Properties.Add("PR_RECIPIENT_FLAGS", "PidTagRecipientFlags");
            Properties.Add("PR_RECIPIENT_NUMBER", "PidTagRecipientNumber");
            Properties.Add("PR_RECIPIENT_NUMBER_FOR_ADVICE_A", "PidTagRecipientNumberForAdvice");
            Properties.Add("PR_RECIPIENT_NUMBER_FOR_ADVICE_W", "PidTagRecipientNumberForAdvice");
            Properties.Add("PR_RECIPIENT_NUMBER_FOR_ADVICE", "PidTagRecipientNumberForAdvice");
            Properties.Add("PR_RECIPIENT_PROPOSED", "PidTagRecipientProposed");
            Properties.Add("PR_RECIPIENT_PROPOSEDENDTIME", "PidTagRecipientProposedEndTime");
            Properties.Add("PR_RECIPIENT_PROPOSEDSTARTTIME", "PidTagRecipientProposedStartTime");
            Properties.Add("PR_RECIPIENT_REASSIGNMENT_PROHIBITED", "PidTagRecipientReassignmentProhibited");
            Properties.Add("PR_RECIPIENT_STATUS", "PidTagRecipientStatus");
            Properties.Add("PR_RECIPIENT_TRACKSTATUS_TIME", "PidTagRecipientTrackStatusTime");
            Properties.Add("PR_RECIPIENT_TRACKSTATUS", "PidTagRecipientTrackStatus");
            Properties.Add("PR_RECIPIENT_TYPE", "PidTagRecipientType");
            Properties.Add("PR_RECORD_KEY", "PidTagRecordKey");
            Properties.Add("PR_REDIRECTION_HISTORY", "PidTagRedirectionHistory");
            Properties.Add("PR_REFERRED_BY_NAME_A", "PidTagReferredByName");
            Properties.Add("PR_REFERRED_BY_NAME_W", "PidTagReferredByName");
            Properties.Add("PR_REFERRED_BY_NAME", "PidTagReferredByName");
            Properties.Add("PR_REGISTERED_MAIL_TYPE", "PidTagRegisteredMailType");
            Properties.Add("PR_RELATED_IPMS", "PidTagRelatedMessageIds");
            Properties.Add("PR_REM_ONLINE_ENTRYID", "PidTagRemindersOnlineEntryId");
            Properties.Add("PR_REMOTE_PROGRESS_TEXT_A", "PidTagRemoteProgressText");
            Properties.Add("PR_REMOTE_PROGRESS_TEXT_W", "PidTagRemoteProgressText");
            Properties.Add("PR_REMOTE_PROGRESS_TEXT", "PidTagRemoteProgressText");
            Properties.Add("PR_REMOTE_PROGRESS", "PidTagRemoteProgress");
            Properties.Add("PR_REMOTE_VALIDATE_OK", "PidTagRemoteValidateOk");
            Properties.Add("PR_RENDERING_POSITION", "PidTagRenderingPosition");
            Properties.Add("PR_REPLY_RECIPIENT_ENTRIES", "PidTagReplyRecipientEntries");
            Properties.Add("PR_REPLY_RECIPIENT_NAMES_A", "PidTagReplyRecipientNames");
            Properties.Add("PR_REPLY_RECIPIENT_NAMES_W", "PidTagReplyRecipientNames");
            Properties.Add("PR_REPLY_RECIPIENT_NAMES", "PidTagReplyRecipientNames");
            Properties.Add("PR_REPLY_REQUESTED", "PidTagReplyRequested");
            Properties.Add("PR_REPLY_TEMPLATE_ID", "PidTagReplyTemplateId");
            Properties.Add("PR_REPLY_TIME", "PidTagReplyTime");
            Properties.Add("PR_REPORT_DISPOSITION", "PidTagReportDisposition");
            Properties.Add("PR_REPORT_DISPOSITION_A", "PidTagReportDisposition");
            Properties.Add("PR_REPORT_DISPOSITION_W", "PidTagReportDisposition");
            Properties.Add("PR_REPORT_DISPOSITION_MODE", "PidTagReportDispositionMode");
            Properties.Add("PR_REPORT_DISPOSITION_MODE_A", "PidTagReportDispositionMode");
            Properties.Add("PR_REPORT_DISPOSITION_MODE_W", "PidTagReportDispositionMode");
            Properties.Add("PR_REPORT_DISPOSITION_OPTIONS", "PidTagReportDispositionOptions");
            Properties.Add("PR_REPORT_DISPOSITION_OPTIONS_A", "PidTagReportDispositionOptions");
            Properties.Add("PR_REPORT_DISPOSITION_OPTIONS_W", "PidTagReportDispositionOptions");
            Properties.Add("PR_REPORT_DISPOSITION_TO_EMAIL_ADDRESSES", "PidTagReportDispositionToEmailAddresses");
            Properties.Add("PR_REPORT_DISPOSITION_TO_EMAIL_ADDRESSES_A", "PidTagReportDispositionToEmailAddresses");
            Properties.Add("PR_REPORT_DISPOSITION_TO_EMAIL_ADDRESSES_W", "PidTagReportDispositionToEmailAddresses");
            Properties.Add("PR_REPORT_DISPOSITION_TO_NAMES", "PidTagReportDispositionToNames");
            Properties.Add("PR_REPORT_DISPOSITION_TO_NAMES_A", "PidTagReportDispositionToNames");
            Properties.Add("PR_REPORT_DISPOSITION_TO_NAMES_W", "PidTagReportDispositionToNames");
            Properties.Add("PR_REPORT_ENTRYID", "PidTagReportEntryId");
            Properties.Add("PR_REPORT_NAME_A", "PidTagReportName");
            Properties.Add("PR_REPORT_NAME_W", "PidTagReportName");
            Properties.Add("PR_REPORT_NAME", "PidTagReportName");
            Properties.Add("PR_REPORT_ORIGINAL_SENDER", "PidTagReportOriginalSender");
            Properties.Add("PR_REPORT_ORIGINAL_SENDER_A", "PidTagReportOriginalSender");
            Properties.Add("PR_REPORT_ORIGINAL_SENDER_W", "PidTagReportOriginalSender");
            Properties.Add("PR_REPORT_SEARCH_KEY", "PidTagReportSearchKey");
            Properties.Add("PR_REPORT_TAG", "PidTagReportTag");
            Properties.Add("PR_REPORT_TEXT_A", "PidTagReportText");
            Properties.Add("PR_REPORT_TEXT_W", "PidTagReportText");
            Properties.Add("PR_REPORT_TEXT", "PidTagReportText");
            Properties.Add("PR_REPORT_TIME", "PidTagReportTime");
            Properties.Add("PR_REPORTING_DL_NAME", "PidTagReportingDistributionListName");
            Properties.Add("PR_REPORTING_MTA_CERTIFICATE", "PidTagReportingMessageTransferAgentCertificate");
            Properties.Add("PR_REQUESTED_DELIVERY_METHOD", "PidTagRequestedDeliveryMethod");
            Properties.Add("PR_RESOLVE_METHOD", "PidTagResolveMethod");
            Properties.Add("PR_RESOURCE_FLAGS", "PidTagResourceFlags");
            Properties.Add("PR_RESOURCE_METHODS", "PidTagResourceMethods");
            Properties.Add("PR_RESOURCE_PATH_A", "PidTagResourcePath");
            Properties.Add("PR_RESOURCE_PATH_W", "PidTagResourcePath");
            Properties.Add("PR_RESOURCE_PATH", "PidTagResourcePath");
            Properties.Add("PR_RESOURCE_TYPE", "PidTagResourceType");
            Properties.Add("PR_RESPONSE_REQUESTED", "PidTagResponseRequested");
            Properties.Add("PR_RESPONSIBILITY", "PidTagResponsibility");
            Properties.Add("PR_RETURNED_IPM", "PidTagReturnedMessageid");
            Properties.Add("PR_ROAMING_BINARYSTREAM", "PidTagRoamingBinary");
            Properties.Add("PR_ROAMING_DATATYPES", "PidTagRoamingDatatypes");
            Properties.Add("PR_ROAMING_DICTIONARY", "PidTagRoamingDictionary");
            Properties.Add("PR_ROAMING_XMLSTREAM", "PidTagRoamingXmlStream");
            Properties.Add("PR_ROH_FLAGS", "PidTagRpcOverHttpFlags");
            Properties.Add("PR_ROH_PROXY_AUTH_SCHEME", "PidTagRpcOverHttpProxyAuthScheme");
            Properties.Add("PR_ROH_PROXY_PRINCIPAL_NAME", "PidTagRpcOverHttpProxyPrincipalName");
            Properties.Add("PR_ROH_PROXY_SERVER", "PidTagRpcOverHttpProxyServer");
            Properties.Add("PR_ROW_TYPE", "PidTagRowType");
            Properties.Add("PR_ROWID", "PidTagRowid");
            Properties.Add("PR_RTF_COMPRESSED", "PidTagRtfCompressed");
            Properties.Add("PR_RTF_IN_SYNC", "PidTagRtfInSync");
            Properties.Add("PR_RTF_SYNC_BODY_COUNT", "PidTagRtfSyncBodyCount");
            Properties.Add("PR_RTF_SYNC_BODY_CRC", "PidTagRtfSyncBodyCrc");
            Properties.Add("PR_RTF_SYNC_BODY_TAG_A", "PidTagRtfSyncBodyTag");
            Properties.Add("PR_RTF_SYNC_BODY_TAG_W", "PidTagRtfSyncBodyTag");
            Properties.Add("PR_RTF_SYNC_BODY_TAG", "PidTagRtfSyncBodyTag");
            Properties.Add("PR_RTF_SYNC_PREFIX_COUNT", "PidTagRtfSyncPrefixCount");
            Properties.Add("PR_RTF_SYNC_TRAILING_COUNT", "PidTagRtfSyncTrailingCount");
            Properties.Add("PR_RULE_ACTIONS", "PidTagRuleActions");
            Properties.Add("PR_RULE_CONDITION", "PidTagRuleCondition");
            Properties.Add("PR_RULE_ID", "PidTagRuleId");
            Properties.Add("PR_RULE_LEVEL", "PidTagRuleLevel");
            Properties.Add("PR_RULE_MSG_NAME", "PidTagRuleMsgName");
            Properties.Add("PR_RULE_MSG_PROVIDER", "PidTagRuleMsgProvider");
            Properties.Add("PR_RULE_NAME", "PidTagRuleName");
            Properties.Add("PR_RULE_PROVIDER", "PidTagRuleProvider");
            Properties.Add("PR_RULE_PROVIDER_DATA", "PidTagRuleProviderData");
            Properties.Add("PR_RULE_SEQUENCE", "PidTagRuleSequence");
            Properties.Add("PR_RULE_STATE", "PidTagRuleState");
            Properties.Add("PR_RULE_USER_FLAGS", "PidTagRuleUserFlags");
            Properties.Add("PR_RULES_TABLE", "PidTagRulesTable");
            Properties.Add("PR_SCHDINFO_APPT_TOMBSTONE", "PidTagScheduleInfoAppointmentTombstone");
            Properties.Add("PR_SCHDINFO_AUTO_ACCEPT_APPTS", "PidTagScheduleInfoAutoAcceptAppointments");
            Properties.Add("PR_SCHDINFO_BOSS_WANTS_COPY", "PidTagScheduleInfoDelegatorWantsCopy");
            Properties.Add("PR_SCHDINFO_BOSS_WANTS_INFO", "PidTagScheduleInfoDelegatorWantsInfo");
            Properties.Add("PR_SCHDINFO_DELEGATE_ENTRYIDS", "PidTagScheduleInfoDelegateEntryIds");
            Properties.Add("PR_SCHDINFO_DELEGATE_NAMES", "PidTagScheduleInfoDelegateNames");
            Properties.Add("PR_SCHDINFO_DISALLOW_OVERLAPPING_APPTS", "PidTagScheduleInfoDisallowOverlappingAppts");
            Properties.Add("PR_SCHDINFO_DISALLOW_RECURRING_APPTS", "PidTagScheduleInfoDisallowRecurringAppts");
            Properties.Add("PR_SCHDINFO_DONT_MAIL_DELEGATES", "PidTagScheduleInfoDontMailDelegates");
            Properties.Add("PR_SCHDINFO_FREEBUSY_BUSY", "PidTagScheduleInfoFreeBusyBusy");
            Properties.Add("PR_SCHDINFO_FREEBUSY_MERGED", "PidTagScheduleInfoFreeBusyMerged");
            Properties.Add("PR_SCHDINFO_FREEBUSY_OOF", "PidTagScheduleInfoFreeBusyAway");
            Properties.Add("PR_SCHDINFO_FREEBUSY_TENTATIVE", "PidTagScheduleInfoFreeBusyTentative");
            Properties.Add("PR_SCHDINFO_FREEBUSY", "PidTagScheduleInfoFreeBusy");
            Properties.Add("PR_SCHDINFO_MONTHS_BUSY", "PidTagScheduleInfoMonthsBusy");
            Properties.Add("PR_SCHDINFO_MONTHS_MERGED", "PidTagScheduleInfoMonthsMerged");
            Properties.Add("PR_SCHDINFO_MONTHS_OOF", "PidTagScheduleInfoMonthsAway");
            Properties.Add("PR_SCHDINFO_MONTHS_TENTATIVE", "PidTagScheduleInfoMonthsTentative");
            Properties.Add("PR_SCHDINFO_RESOURCE_TYPE", "PidTagScheduleInfoResourceType");
            Properties.Add("PR_SEARCH_KEY", "PidTagSearchKey");
            Properties.Add("PR_SEARCH", "PidTagSearch");
            Properties.Add("PR_SEARCH_ATTACHMENTS_W", "PidTagSearchAttachments");
            Properties.Add("PR_SEARCH_RECIP_EMAIL_BCC_W", "PidTagSearchRecipientEmailBcc");
            Properties.Add("PR_SEARCH_RECIP_EMAIL_CC_W", "PidTagSearchRecipientEmailCc");
            Properties.Add("PR_SEARCH_RECIP_EMAIL_TO_W", "PidTagSearchRecipientEmailTo");
            Properties.Add("PR_SELECTABLE", "PidTagSelectable");
            Properties.Add("PR_SEND_INTERNET_ENCODING", "PidTagSendInternetEncoding");
            Properties.Add("PR_SEND_RICH_INFO", "PidTagSendRichInfo");
            Properties.Add("PR_SENDER_ADDRTYPE_A", "PidTagSenderAddressType");
            Properties.Add("PR_SENDER_ADDRTYPE_W", "PidTagSenderAddressType");
            Properties.Add("PR_SENDER_ADDRTYPE", "PidTagSenderAddressType");
            Properties.Add("PR_SENDER_EMAIL_ADDRESS_A", "PidTagSenderEmailAddress");
            Properties.Add("PR_SENDER_EMAIL_ADDRESS_W", "PidTagSenderEmailAddress");
            Properties.Add("PR_SENDER_EMAIL_ADDRESS", "PidTagSenderEmailAddress");
            Properties.Add("PR_SENDER_ENTRYID", "PidTagSenderEntryId");
            Properties.Add("PR_SENDER_NAME_A", "PidTagSenderName");
            Properties.Add("PR_SENDER_NAME_W", "PidTagSenderName");
            Properties.Add("PR_SENDER_NAME", "PidTagSenderName");
            Properties.Add("PR_SENDER_SEARCH_KEY", "PidTagSenderSearchKey");
            Properties.Add("PR_SENDER_SMTP_ADDRESS_A", "PidTagSenderSmtpAddress");
            Properties.Add("PR_SENDER_SMTP_ADDRESS_W", "PidTagSenderSmtpAddress");
            Properties.Add("PR_SENDER_SMTP_ADDRESS", "PidTagSenderSmtpAddress");
            Properties.Add("PR_SENSITIVITY", "PidTagSensitivity");
            Properties.Add("PR_SENT_REPRESENTING_ADDRTYPE_A", "PidTagSentRepresentingAddressType");
            Properties.Add("PR_SENT_REPRESENTING_ADDRTYPE_W", "PidTagSentRepresentingAddressType");
            Properties.Add("PR_SENT_REPRESENTING_ADDRTYPE", "PidTagSentRepresentingAddressType");
            Properties.Add("PR_SENT_REPRESENTING_EMAIL_ADDRESS_A", "PidTagSentRepresentingEmailAddress");
            Properties.Add("PR_SENT_REPRESENTING_EMAIL_ADDRESS_W", "PidTagSentRepresentingEmailAddress");
            Properties.Add("PR_SENT_REPRESENTING_EMAIL_ADDRESS", "PidTagSentRepresentingEmailAddress");
            Properties.Add("PR_SENT_REPRESENTING_ENTRYID", "PidTagSentRepresentingEntryId");
            Properties.Add("PR_SENT_REPRESENTING_NAME_A", "PidTagSentRepresentingName");
            Properties.Add("PR_SENT_REPRESENTING_NAME_W", "PidTagSentRepresentingName");
            Properties.Add("PR_SENT_REPRESENTING_NAME", "PidTagSentRepresentingName");
            Properties.Add("PR_SENT_REPRESENTING_SEARCH_KEY", "PidTagSentRepresentingSearchKey");
            Properties.Add("PR_SENT_REPRESENTING_SMTP_ADDRESS_A", "PidTagSentRepresentingSmtpAddress");
            Properties.Add("PR_SENT_REPRESENTING_SMTP_ADDRESS_W", "PidTagSentRepresentingSmtpAddress");
            Properties.Add("PR_SENT_REPRESENTING_SMTP_ADDRESS", "PidTagSentRepresentingSmtpAddress");
            Properties.Add("PR_SENTMAIL_ENTRYID", "PidTagSentMailEntryId");
            Properties.Add("PR_SERVICE_DELETE_FILES_A", "PidTagServiceDeleteFiles");
            Properties.Add("PR_SERVICE_DELETE_FILES_W", "PidTagServiceDeleteFiles");
            Properties.Add("PR_SERVICE_DELETE_FILES", "PidTagServiceDeleteFiles");
            Properties.Add("PR_SERVICE_DLL_NAME_A", "PidTagServiceDllName");
            Properties.Add("PR_SERVICE_DLL_NAME_W", "PidTagServiceDllName");
            Properties.Add("PR_SERVICE_DLL_NAME", "PidTagServiceDllName");
            Properties.Add("PR_SERVICE_ENTRY_NAME", "PidTagServiceEntryName");
            Properties.Add("PR_SERVICE_EXTRA_UIDS", "PidTagServiceExtraUids");
            Properties.Add("PR_SERVICE_INSTALL_ID_A", "PidTagServiceInstallId");
            Properties.Add("PR_SERVICE_INSTALL_ID_W", "PidTagServiceInstallId");
            Properties.Add("PR_SERVICE_INSTALL_ID", "PidTagServiceInstallId");
            Properties.Add("PR_SERVICE_NAME_A", "PidTagServiceName");
            Properties.Add("PR_SERVICE_NAME_W", "PidTagServiceName");
            Properties.Add("PR_SERVICE_NAME", "PidTagServiceName");
            Properties.Add("PR_SERVICE_SUPPORT_FILES_A", "PidTagServiceSupportFiles");
            Properties.Add("PR_SERVICE_SUPPORT_FILES_W", "PidTagServiceSupportFiles");
            Properties.Add("PR_SERVICE_SUPPORT_FILES", "PidTagServiceSupportFiles");
            Properties.Add("PR_SERVICE_UID", "PidTagServiceUid");
            Properties.Add("PR_SERVICES", "PidTagServices");
            Properties.Add("PR_SMTP_ADDRESS_A", "PidTagSmtpAddress");
            Properties.Add("PR_SMTP_ADDRESS_W", "PidTagSmtpAddress");
            Properties.Add("PR_SMTP_ADDRESS", "PidTagSmtpAddress");
            Properties.Add("PR_SPOOLER_STATUS", "PidTagSpoolerStatus");
            Properties.Add("PR_SPOUSE_NAME_A", "PidTagSpouseName");
            Properties.Add("PR_SPOUSE_NAME_W", "PidTagSpouseName");
            Properties.Add("PR_SPOUSE_NAME", "PidTagSpouseName");
            Properties.Add("PR_START_DATE", "PidTagStartDate");
            Properties.Add("PR_STATE_OR_PROVINCE_A", "PidTagStateOrProvince");
            Properties.Add("PR_STATE_OR_PROVINCE_W", "PidTagStateOrProvince");
            Properties.Add("PR_STATE_OR_PROVINCE", "PidTagStateOrProvince");
            Properties.Add("PR_STATUS_CODE", "PidTagStatusCode");
            Properties.Add("PR_STATUS_STRING_A", "PidTagStatusString");
            Properties.Add("PR_STATUS_STRING_W", "PidTagStatusString");
            Properties.Add("PR_STATUS_STRING", "PidTagStatusString");
            Properties.Add("PR_STATUS", "PidTagStatus");
            Properties.Add("PR_STORE_ENTRYID", "PidTagStoreEntryId");
            Properties.Add("PR_STORE_ENTRYID_EMSMDB_V1", "PidTagStoreEntryIdEmsmdbV1");
            Properties.Add("PR_STORE_PROVIDERS", "PidTagStoreProviders");
            Properties.Add("PR_STORE_RECORD_KEY", "PidTagStoreRecordKey");
            Properties.Add("PR_STORE_STATE", "PidTagStoreState");
            Properties.Add("PR_STORE_SUPPORT_MASK", "PidTagStoreSupportMask");
            Properties.Add("PR_STORE_UNICODE_MASK", "PidTagStoreUnicodeMask");
            Properties.Add("PR_STREET_ADDRESS_A", "PidTagStreetAddress");
            Properties.Add("PR_STREET_ADDRESS_W", "PidTagStreetAddress");
            Properties.Add("PR_STREET_ADDRESS", "PidTagStreetAddress");
            Properties.Add("PR_SUBFOLDERS", "PidTagSubfolders");
            Properties.Add("PR_SUBJECT_A", "PidTagSubject");
            Properties.Add("PR_SUBJECT_IPM", "PidTagSubjectMessageId");
            Properties.Add("PR_SUBJECT_PREFIX_A", "PidTagSubjectPrefix");
            Properties.Add("PR_SUBJECT_PREFIX_W", "PidTagSubjectPrefix");
            Properties.Add("PR_SUBJECT_PREFIX", "PidTagSubjectPrefix");
            Properties.Add("PR_SUBJECT_W", "PidTagSubject");
            Properties.Add("PR_SUBJECT", "PidTagSubject");
            Properties.Add("PR_SUBMIT_FLAGS", "PidTagSubmitFlags");
            Properties.Add("PR_SUPPLEMENTARY_INFO_A", "PidTagSupplementaryInfo");
            Properties.Add("PR_SUPPLEMENTARY_INFO_W", "PidTagSupplementaryInfo");
            Properties.Add("PR_SUPPLEMENTARY_INFO", "PidTagSupplementaryInfo");
            Properties.Add("PR_SURNAME_A", "PidTagSurname");
            Properties.Add("PR_SURNAME_W", "PidTagSurname");
            Properties.Add("PR_SURNAME", "PidTagSurname");
            Properties.Add("PR_SWAPPED_TODO_DATA", "PidTagSwappedToDoData");
            Properties.Add("PR_SWAPPED_TODO_STORE", "PidTagSwappedToDoStore");
            Properties.Add("PR_TELEX_NUMBER_A", "PidTagTelexNumber");
            Properties.Add("PR_TELEX_NUMBER_W", "PidTagTelexNumber");
            Properties.Add("PR_TELEX_NUMBER", "PidTagTelexNumber");
            Properties.Add("PR_TEMPLATEID", "PidTagTemplateid");
            Properties.Add("PR_TITLE_A", "PidTagTitle");
            Properties.Add("PR_TITLE_W", "PidTagTitle");
            Properties.Add("PR_TITLE", "PidTagTitle");
            Properties.Add("PR_TNEF_CORRELATION_KEY", "PidTagTnefCorrelationKey");
            Properties.Add("PR_TNEF_UNPROCESSED_PROPS", "PidTagTnefUnprocessedProps");
            Properties.Add("PR_TODO_ITEM_FLAGS", "PidTagToDoItemFlags");
            Properties.Add("PR_TRANSMITABLE_DISPLAY_NAME_A", "PidTagTransmittableDisplayName");
            Properties.Add("PR_TRANSMITABLE_DISPLAY_NAME_W", "PidTagTransmittableDisplayName");
            Properties.Add("PR_TRANSMITABLE_DISPLAY_NAME", "PidTagTransmittableDisplayName");
            Properties.Add("PR_TRANSPORT_KEY", "PidTagTransportKey");
            Properties.Add("PR_TRANSPORT_MESSAGE_HEADERS_A", "PidTagTransportMessageHeaders");
            Properties.Add("PR_TRANSPORT_MESSAGE_HEADERS_W", "PidTagTransportMessageHeaders");
            Properties.Add("PR_TRANSPORT_MESSAGE_HEADERS", "PidTagTransportMessageHeaders");
            Properties.Add("PR_TRANSPORT_PROVIDERS", "PidTagTransportProviders");
            Properties.Add("PR_TTYTDD_PHONE_NUMBER_A", "PidTagTelecommunicationsDeviceForDeafTelephoneNumber");
            Properties.Add("PR_TTYTDD_PHONE_NUMBER_W", "PidTagTelecommunicationsDeviceForDeafTelephoneNumber");
            Properties.Add("PR_TTYTDD_PHONE_NUMBER", "PidTagTtyTddPhoneNumber");
            Properties.Add("PR_TTYTDD_PHONE_NUMBER", "PidTagTelecommunicationsDeviceForDeafTelephoneNumber");
            Properties.Add("PR_TYPE_OF_MTS_USER", "PidTagTypeOfX400User");
            Properties.Add("PR_URL_COMP_NAME_A", "PidTagUrlComponentName");
            Properties.Add("PR_URL_COMP_NAME_W", "PidTagUrlComponentName");
            Properties.Add("PR_URL_COMP_NAME", "PidTagUrlComponentName");
            Properties.Add("PR_USER_CERTIFICATE", "PidTagUserCertificate");
            Properties.Add("PR_USER_X509_CERTIFICATE", "PidTagUserX509Certificate");
            Properties.Add("PR_VALID_FOLDER_MASK", "PidTagValidFolderMask");
            Properties.Add("PR_VD_NAME_W", "PidTagViewDescriptorName");
            Properties.Add("PR_VD_NAME", "PidTagViewDescriptorName");
            Properties.Add("PR_VD_VERSION", "PidTagViewDescriptorVersion");
            Properties.Add("PR_VIEWS_ENTRYID", "PidTagViewsEntryId");
            Properties.Add("PR_WB_SF_DEFINITION", "PidTagSearchFolderDefinition");
            Properties.Add("PR_WB_SF_EFP_FLAGS", "PidTagSearchFolderEfpFlags");
            Properties.Add("PR_WB_SF_EXPIRATION", "PidTagSearchFolderExpiration");
            Properties.Add("PR_WB_SF_ID", "PidTagSearchFolderId");
            Properties.Add("PR_WB_SF_LAST_USED", "PidTagSearchFolderLastUsed");
            Properties.Add("PR_WB_SF_STORAGE_TYPE", "PidTagSearchFolderStorageType");
            Properties.Add("PR_WB_SF_TAG", "PidTagSearchFolderTag");
            Properties.Add("PR_WB_SF_TEMPLATE_ID", "PidTagSearchFolderTemplateId");
            Properties.Add("PR_WEDDING_ANNIVERSARY", "PidTagWeddingAnniversary");
            Properties.Add("PR_WIZARD_NO_PAB_PAGE", "PidTagWizardNoPabPage");
            Properties.Add("PR_WIZARD_NO_PST_PAGE", "PidTagWizardNoPstPage");
            Properties.Add("PR_X400_CONTENT_TYPE", "PidTagX400ContentType");
            Properties.Add("PR_XPOS", "PidTagXCoordinate");
            Properties.Add("PR_YPOS", "PidTagYCoordinate");
        }
        #endregion

        #region PropertyNameToCanonical
        /// <summary>
        ///     Returns the canonical name of the give <paramref name="propertyName" />. When the property does not
        ///     exists then <c>null</c> is returned
        /// </summary>
        /// <param name="propertyName"></param>
        /// <returns></returns>
        internal static string PropertyNameToCanonical(string propertyName)
        {
            return Properties.ContainsKey(propertyName)
                ? Properties[propertyName]
                : null;
        }
        #endregion

        #region CanonicalToPropertyName
        /// <summary>
        ///     Returns the property name of the give <paramref name="canonicalName" />. When the property does not
        ///     exists then <c>null</c> is returned
        /// </summary>
        /// <remarks>
        ///     When more then one property is found then the UNICODE property is returned instead
        ///     of it's Non-UNICODE counter parts
        /// </remarks>
        /// <param name="canonicalName">The canonical name of the <see cref="PropertyTags"/></param>
        /// <returns></returns>
        internal static string CanonicalToPropertyName(string canonicalName)
        {
            var matches = Properties.Where(m => m.Value.StartsWith(canonicalName)).Select(m => m.Key);
            var enumerable = matches as string[] ?? matches.ToArray();
            return enumerable.Count() == 1 ? enumerable.First() : enumerable.First(m => m.EndsWith("_W"));
        }
        #endregion
    }
}